@@ -29,8 +29,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <telepathy-glib/channel.h>
-#include <telepathy-glib/dbus-properties-mixin.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "mcd-mission.h"
 
@@ -80,8 +79,8 @@ struct _McdChannelClass
     /* signals */
     void (*status_changed_signal) (McdChannel * channel,
 				   McdChannelStatus status);
-    void (*members_accepted_signal) (McdChannel *channel);
-    TpDBusPropertiesMixinClass dbus_properties_class;
+    void (*_former_members_accepted_signal) (void);
+    TpDBusPropertiesMixinClass _former_dbus_properties_class;
     void (*_mc_reserved1) (void);
     void (*_mc_reserved2) (void);
     void (*_mc_reserved3) (void);
@@ -99,25 +98,9 @@ McdChannel *mcd_channel_new_from_path (TpConnection *connection,
                                        const gchar *object_path,
                                        const gchar *type, guint handle,
                                        TpHandleType handle_type);
-McdChannel *mcd_channel_new_request (McdAccount *account,
-                                     DBusGConnection *dgc,
-                                     GHashTable *properties,
-                                     gint64 user_time,
-                                     const gchar *preferred_handler,
-                                     GHashTable *request_metadata,
-                                     gboolean use_existing,
-                                     gboolean proceeding);
 
 McdChannelStatus mcd_channel_get_status (McdChannel * channel);
-gboolean mcd_channel_get_members_accepted (McdChannel *channel);
-const gchar* mcd_channel_get_channel_type (McdChannel *channel);
-GQuark mcd_channel_get_channel_type_quark (McdChannel *channel);
 const gchar* mcd_channel_get_object_path (McdChannel *channel);
-guint mcd_channel_get_handle (McdChannel *channel);
-TpHandleType mcd_channel_get_handle_type (McdChannel *channel);
-const gchar *mcd_channel_get_name (McdChannel *channel);
-const gchar *mcd_channel_get_inviter (McdChannel *channel);
-gboolean mcd_channel_is_missed (McdChannel *channel);
 gboolean mcd_channel_is_requested (McdChannel *channel);
 McdAccount *mcd_channel_get_account (McdChannel *channel);
 TpChannel *mcd_channel_get_tp_channel (McdChannel *channel);
