@@ -79,45 +79,21 @@ enum
 static GQuark readiness_quark = 0;
 
 static void
-on_manager_ready (TpConnectionManager *tp_conn_mgr, const GError *error,
-                  gpointer user_data, GObject *weak_object)
+on_manager_ready (GObject *source_object,
+                  GAsyncResult *result, gpointer user_data)
 {
-    McdManager *manager = MCD_MANAGER (weak_object);
+    TpConnectionManager *tp_conn_mgr = TP_CONNECTION_MANAGER (source_object);
+    McdManager *manager = MCD_MANAGER (user_data);
     McdManagerPrivate *priv;
+    GError *error = NULL;
+
+    tp_proxy_prepare_finish (tp_conn_mgr, result, &error);
 
     priv = manager->priv;
     DEBUG ("manager %s is ready", priv->name);
     priv->ready = TRUE;
     _mcd_object_ready (manager, readiness_quark, error);
-}
-
-static gint
-_find_connection_by_path (gconstpointer data, gconstpointer user_data)
-{
-    TpConnection *tp_conn;
-    McdConnection *connection = MCD_CONNECTION (data);
-    const gchar *object_path = (const gchar *)user_data;
-    const gchar *conn_object_path = NULL;
-    gint ret;
-
-    if (!data) return 1;
-
-    g_object_get (G_OBJECT (connection), "tp-connection",
-		  &tp_conn, NULL);
-    if (!tp_conn)
-	return 1;
-    conn_object_path = TP_PROXY (tp_conn)->object_path;
-    if (strcmp (conn_object_path, object_path) == 0)
-    {
-	ret = 0;
-    }
-    else
-    {
-	ret = 1;
-    }
-    
-    g_object_unref (G_OBJECT (tp_conn));
-    return ret;
+    g_clear_error (&error);
 }
 
 static void
@@ -198,8 +174,7 @@ mcd_manager_setup (McdManager *manager)
         goto error;
     }
 
-    tp_connection_manager_call_when_ready (priv->tp_conn_mgr, on_manager_ready,
-                                           NULL, NULL, (GObject *)manager);
+    tp_proxy_prepare_async (priv->tp_conn_mgr, NULL, on_manager_ready, manager);
 
     DEBUG ("Manager %s created", priv->name);
     return TRUE;
@@ -284,20 +259,6 @@ _mcd_manager_get_property (GObject * obj, guint prop_id,
     }
 }
 
-static McdConnection *
-create_connection (McdManager *manager, McdAccount *account)
-{
-    McdManagerPrivate *priv = manager->priv;
-
-    return g_object_new (MCD_TYPE_CONNECTION,
-                         "dbus-daemon", priv->dbus_daemon,
-                         "tp-manager", priv->tp_conn_mgr,
-                         "dispatcher", priv->dispatcher,
-                         "account", account,
-                         "slacker", priv->slacker,
-                         NULL);
-}
-
 static void
 mcd_manager_class_init (McdManagerClass * klass)
 {
@@ -315,8 +276,6 @@ mcd_manager_class_init (McdManagerClass * klass)
     mission_class->connect = _mcd_manager_connect;
     mission_class->disconnect = _mcd_manager_disconnect;
 
-    klass->create_connection = create_connection;
-
     /* Properties */
     g_object_class_install_property
         (object_class, PROP_NAME,
@@ -364,48 +323,6 @@ mcd_manager_new (const gchar *unique_name,
     return obj;
 }
 
-McdConnection *
-mcd_manager_get_connection (McdManager * manager, const gchar *object_path)
-{
-    const GList *connections;
-    const GList *node;
-
-    connections = mcd_operation_get_missions (MCD_OPERATION (manager));
-    node = g_list_find_custom ((GList*)connections, object_path,
-			       _find_connection_by_path);
-
-    if (node != NULL)
-    {
-	return MCD_CONNECTION (node->data);
-    }
-
-    else
-    {
-	return NULL;
-    }
-}
-
-gboolean
-mcd_manager_cancel_channel_request (McdManager *manager, guint operation_id,
-				    const gchar *requestor_client_id,
-				    GError **error)
-{
-    const GList *connections, *node;
-
-    connections = mcd_operation_get_missions (MCD_OPERATION (manager));
-    if (!connections) return FALSE;
-
-    for (node = connections; node; node = node->next)
-    {
-	if (mcd_connection_cancel_channel_request (MCD_CONNECTION (node->data),
-						   operation_id,
-						   requestor_client_id,
-						   error))
-	    return TRUE;
-    }
-    return FALSE;
-}
-
 /**
  * mcd_manager_get_unique_name:
  * @manager: the #McdManager.
@@ -468,8 +385,14 @@ mcd_manager_create_connection (McdManager *manager, McdAccount *account)
     g_return_val_if_fail (MCD_IS_MANAGER (manager), NULL);
     g_return_val_if_fail (manager->priv->tp_conn_mgr != NULL, NULL);
 
-    connection = MCD_MANAGER_GET_CLASS (manager)->create_connection
-        (manager, account);
+    connection = g_object_new (MCD_TYPE_CONNECTION,
+                               "dbus-daemon", manager->priv->dbus_daemon,
+                               "tp-manager", manager->priv->tp_conn_mgr,
+                               "dispatcher", manager->priv->dispatcher,
+                               "account", account,
+                               "slacker", manager->priv->slacker,
+                               NULL);
+
     mcd_operation_take_mission (MCD_OPERATION (manager),
 				MCD_MISSION (connection));
     DEBUG ("Created a connection %p for account: %s",
@@ -491,19 +414,6 @@ mcd_manager_get_tp_proxy (McdManager *manager)
     return manager->priv->tp_conn_mgr;
 }
 
-/**
- * mcd_manager_get_dispatcher:
- * @manager: the #McdManager.
- *
- * Returns: the #McdDispatcher.
- */
-McdDispatcher *
-mcd_manager_get_dispatcher (McdManager *manager)
-{
-    g_return_val_if_fail (MCD_IS_MANAGER (manager), NULL);
-    return manager->priv->dispatcher;
-}
-
 /**
  * mcd_manager_call_when_ready:
  * @manager: the #McdManager.
